==> bow-ui-1.2-sources.jar: org/chorem/bow/BowPreferenceHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class BowPreferenceHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private BowPreferenceHelper() {// empty
}

    public static int getTags(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
        return value;
}

    public static int setTags(Wikitty wikitty, int tags) {
        int oldValue = getTags(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS, tags);
        return oldValue;
}

    public static int getBookmarks(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
        return value;
}

    public static int setBookmarks(Wikitty wikitty, int bookmarks) {
        int oldValue = getBookmarks(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS, bookmarks);
        return oldValue;
}

    public static String getColors(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
        return value;
}

    public static String setColors(Wikitty wikitty, String colors) {
        String oldValue = getColors(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS, colors);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowPreference.EXT_BOWPREFERENCE);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowPreferenceAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowPreferenceAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(BowPreference.EXT_BOWPREFERENCE);
}

} //BowPreferenceHelper

==> bow-ui-1.4.1-sources.jar: org/chorem/bow/BowPreferenceHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class BowPreferenceHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private BowPreferenceHelper() {// empty
}

    public static int getTags(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
        return value;
}

    public static int setTags(Wikitty wikitty, int tags) {
        int oldValue = getTags(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS, tags);
        return oldValue;
}

    public static int getBookmarks(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
        return value;
}

    public static int setBookmarks(Wikitty wikitty, int bookmarks) {
        int oldValue = getBookmarks(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS, bookmarks);
        return oldValue;
}

    public static String getColors(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
        return value;
}

    public static String setColors(Wikitty wikitty, String colors) {
        String oldValue = getColors(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS, colors);
        return oldValue;
}

    public static Boolean getScreenshot(Wikitty wikitty) {
        Boolean value = wikitty.getFieldAsBoolean(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_SCREENSHOT);
        return value;
}

    public static Boolean setScreenshot(Wikitty wikitty, Boolean screenshot) {
        Boolean oldValue = getScreenshot(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_SCREENSHOT, screenshot);
        return oldValue;
}

    public static Boolean getFavicon(Wikitty wikitty) {
        Boolean value = wikitty.getFieldAsBoolean(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_FAVICON);
        return value;
}

    public static Boolean setFavicon(Wikitty wikitty, Boolean favicon) {
        Boolean oldValue = getFavicon(wikitty);
        wikitty.setField(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_FAVICON, favicon);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_TAGS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_BOOKMARKS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_COLORS);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_SCREENSHOT);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_SCREENSHOT);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_FAVICON);
            Object f2 = w2.getFieldAsObject(BowPreference.EXT_BOWPREFERENCE, BowPreference.FIELD_BOWPREFERENCE_FAVICON);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowPreference.EXT_BOWPREFERENCE);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowPreferenceAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowPreferenceAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(BowPreference.EXT_BOWPREFERENCE);
}

} //BowPreferenceHelper
